@@ -1,33 +1,35 @@
+C Output from Public domain Ratfor, version 1.01
       subroutine rcorr(xx, n, p, itype, dmat, npair, x, y, rx, ry, work,
-     & iwork)
-      implicit real*8 (a-h,o-z)
+     * iwork)
       integer p, npair(p,p)
-      real*8 xx(n,p), dmat(p,p), x(1), y(1), rx(1), ry(1), work(1)
-      integer*4 iwork(1)
-      real*8 sumx,sumx2,sumy,sumy2,sumxy,z,a,b
-      do 23000 i=1, p 
+      double precision xx(n,p), dmat(p,p), x(1), y(1), rx(1), ry(1), wor
+     *k(1)
+      integer iwork(1)
+      double precision sumx,sumx2,sumy,sumy2,sumxy,z,a,b
+      do23000 i=1, p 
       np=0
-      do 23002 k=1, n 
-      if(.not.(xx(k,i).lt.1d30))goto 23004
+      do23002 k=1, n 
+      if(xx(k,i).lt.1e30)then
       np=np+1
-23004 continue
+      endif
 23002 continue
+23003 continue
       npair(i,i)=np
-      do 23006 j=(i+1),p 
+      do23006 j=(i+1),p 
       m=0
-      if(.not.(itype.eq.1))goto 23008
+      if(itype.eq.1)then
       sumx=0d0
       sumy=0d0
       sumx2=0d0
       sumy2=0d0
       sumxy=0d0
-23008 continue
-      do 23010 k=1,n 
+      endif
+      do23010 k=1,n 
       xk=xx(k,i)
       yk=xx(k,j)
-      if(.not.(xk.lt.1d30 .and. yk.lt.1d30))goto 23012
+      if(xk.lt.1e30 .and. yk.lt.1e30)then
       m=m+1
-      if(.not.(itype.eq.1))goto 23014
+      if(itype.eq.1)then
       a=xk
       b=yk
       sumx=sumx+a
@@ -35,44 +37,45 @@
       sumy=sumy+b
       sumy2=sumy2+b*b
       sumxy=sumxy+a*b
-      goto 23015
-23014 continue
+      else
       x(m)=xk
       y(m)=yk
-23015 continue
-23012 continue
+      endif
+      endif
 23010 continue
+23011 continue
       npair(i,j)=m
-      if(.not.(m.gt.1))goto 23016
-      if(.not.(itype.eq.1))goto 23018
+      if(m.gt.1)then
+      if(itype.eq.1)then
       z=m
-      d=(sumxy-sumx*sumy/z)/dsqrt((sumx2-sumx*sumx/z)*(sumy2-sumy*sumy/
-     &z))
-      goto 23019
-23018 continue
+      d=(sumxy-sumx*sumy/z)/dsqrt((sumx2-sumx*sumx/z)*(sumy2-sumy*sumy/z
+     *))
+      else
       call docorr(x, y, m, d, rx, ry, work, iwork)
-23019 continue
+      endif
       dmat(i,j)=d
-      goto 23017
-23016 continue
-      dmat(i,j)=1d30
-23017 continue
+      else
+      dmat(i,j)=1e30
+      endif
 23006 continue
+23007 continue
 23000 continue
-      do 23020 i=1,p 
-      dmat(i,i)=1d0
-      do 23022 j=(i+1),p 
+23001 continue
+      do23020 i=1,p 
+      dmat(i,i)=1.
+      do23022 j=(i+1),p 
       dmat(j,i)=dmat(i,j)
       npair(j,i)=npair(i,j)
 23022 continue
+23023 continue
 23020 continue
+23021 continue
       return
       end
       subroutine docorr(x, y, n, d, rx, ry, work, iwork)
-      implicit real*8 (a-h,o-z)
-      real*8 x(1), y(1), rx(1), ry(1)
+      double precision x(1), y(1), rx(1), ry(1)
       integer*4 iwork(1)
-      real*8 sumx,sumx2,sumy,sumy2,sumxy,a,b,z
+      double precision sumx,sumx2,sumy,sumy2,sumxy,a,b,z
       call rank(n, x, work, iwork, rx)
       call rank(n, y, work, iwork, ry)
       sumx=0d0
@@ -80,7 +83,7 @@
       sumy=0d0
       sumy2=0d0
       sumxy=0d0
-      do 23024 i=1,n 
+      do23024 i=1,n 
       a=rx(i)
       b=ry(i)
       sumx=sumx+a
@@ -89,8 +92,9 @@
       sumy2=sumy2+b*b
       sumxy=sumxy+a*b
 23024 continue
+23025 continue
       z=n
-      d=(sumxy-sumx*sumy/z)/dsqrt((sumx2-sumx*sumx/z)*(sumy2-sumy*sumy/
-     &z))
+      d=(sumxy-sumx*sumy/z)/dsqrt((sumx2-sumx*sumx/z)*(sumy2-sumy*sumy/z
+     *))
       return
       end
